@@ -19,8 +19,6 @@ class R2RTestCase < ParseTreeTestCase
   def self.generate_test klass, node, data, input_name, output_name
     output_name = data.has_key?('Ruby2Ruby') ? 'Ruby2Ruby' : 'Ruby'
 
-    return if node.to_s =~ /(str_question|not|bang).*_(19|20|21|22|23)$/
-
     klass.class_eval <<-EOM
       def test_#{node}
         pt = #{data[input_name].inspect}
@@ -50,7 +48,6 @@ class TestRuby2Ruby < R2RTestCase
 
   def test_util_dthing_dregx
     inn = util_thingy(:dregx)
-    inn.shift
     out = '/a"b#{(1 + 1)}c"d\/e/'
     exp = /a"b2c"d\/e/
 
@@ -61,7 +58,6 @@ class TestRuby2Ruby < R2RTestCase
 
   def test_util_dthing_dstr
     inn = util_thingy(:dstr)
-    inn.shift
     out = '"a\"b#{(1 + 1)}c\"d/e"'
     exp = 'a"b2c"d/e'
 
@@ -72,7 +68,6 @@ class TestRuby2Ruby < R2RTestCase
 
   def test_util_dthing_dregx_bug?
     inn = s(:dregx, '[\/\"]', s(:evstr, s(:lit, 42)))
-    inn.shift
     out = '/[\/\"]#{42}/'
     exp =  /[\/\"]42/
 
@@ -83,56 +78,56 @@ class TestRuby2Ruby < R2RTestCase
   def test_hash_parens_str
     inn = s(:hash, s(:lit, :k), s(:str, "banana"))
     out = '{ :k => "banana" }'
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_hash_parens_lit
     inn = s(:hash, s(:lit, :k), s(:lit, 0.07))
     out = "{ :k => 0.07 }"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_hash_parens_bool
     inn = s(:hash, s(:lit, :k), s(:true))
     out = "{ :k => true }"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_hash_parens_nil
     inn = s(:hash, s(:lit, :k), s(:nil))
     out = "{ :k => nil }"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_hash_parens_lvar
     inn = s(:hash, s(:lit, :k), s(:lvar, :x))
     out = "{ :k => x }"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_hash_parens_call
     inn = s(:hash, s(:lit, :k), s(:call, nil, :foo, s(:lit, :bar)))
     out = "{ :k => foo(:bar) }"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_hash_parens_iter
     iter = s(:iter, s(:call, nil, :foo), 0, s(:str, "bar"))
     inn = s(:hash, s(:lit, :k), iter)
     out = '{ :k => (foo { "bar" }) }'
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_and_alias
     inn = s(:and, s(:true), s(:alias, s(:lit, :a), s(:lit, :b)))
     out = "true and (alias :a :b)"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_attr_reader_diff
     inn = s(:defn, :same, s(:args), s(:ivar, :@diff))
     out = "def same\n  @diff\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_attr_reader_same
@@ -140,13 +135,13 @@ class TestRuby2Ruby < R2RTestCase
 
     inn = s(:defn, :same, s(:args), s(:ivar, :@same))
     out = "attr_reader :same"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_attr_reader_double
     inn = s(:defn, :same, s(:args), s(:ivar, :@same), s(:ivar, :@diff))
     out = "def same\n  @same\n  @diff\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_attr_reader_same_name_diff_body
@@ -154,26 +149,126 @@ class TestRuby2Ruby < R2RTestCase
 
     inn = s(:defn, :same, s(:args), s(:not, s(:ivar, :@same)))
     out = "def same\n  (not @same)\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_attr_writer_diff
     inn = s(:defn, :same=, s(:args, :o), s(:iasgn, :@diff, s(:lvar, :o)))
     out = "def same=(o)\n  @diff = o\nend"
-    util_compare inn, out
+    assert_parse inn, out
+  end
+
+  def assert_str exp, src
+    assert_equal s(:str, exp), RubyParser.new.process(src)
+  end
+
+  def assert_dstr exp, int, src
+    assert_equal s(:dstr, exp, s(:evstr, int).compact), RubyParser.new.process(src)
+  end
+
+  def assert_r2r exp, sexp
+    assert_equal exp, Ruby2Ruby.new.process(sexp)
+  end
+
+  def assert_rt src, exp=src.dup
+    assert_equal exp, Ruby2Ruby.new.process(RubyParser.new.parse(src))
+  end
+
+  def test_bug_033
+    # gentle reminder to keep some sanity
+    #
+    # Use %q("...") for raw input strings
+    # Use %q(...) for raw output to avoid double-\'s
+    # Use %(...) for output strings
+    #
+    # don't use '...' at all
+    # only use  "..." within sexps
+
+    # "\t"
+    assert_str %(\t),     %q("\t")
+    assert_r2r %q("\\t"), s(:str, "\t")
+    assert_rt  %q("\t")
+
+    # "\\t"
+    assert_str %(\t),     %q("\\t")
+    assert_r2r %q("\\t"), s(:str, "\t")
+    assert_rt  %q("\\t")
+
+    # "\\\\t"
+    assert_str %(\\t),      %q("\\\\t")
+    assert_r2r %q("\\\\t"), s(:str, "\\t")
+    assert_rt  %q("\\\\t")
+
+    # "\t#{}"
+    assert_dstr %(\t), nil,  %q("\t#{}")
+    assert_r2r  %q("\t#{}"), s(:dstr, "\t", s(:evstr))
+    assert_rt   %q("\t#{}")
+
+    # "\\t#{}"
+    assert_dstr %(\t), nil,   %q("\\t#{}")
+    assert_r2r  %q("\\t#{}"), s(:dstr, "\t", s(:evstr))
+    assert_rt   %q("\\t#{}")
+
+    # "\\\\t#{}"
+    assert_dstr %(\\t), nil,    %q("\\\\t#{}")
+    assert_r2r  %q("\\\\t#{}"), s(:dstr, "\\t", s(:evstr))
+    assert_rt   %q("\\\\t#{}")
+  end
+
+  def test_bug_043
+    inn = s(:defn, :check, s(:args),
+            s(:rescue,
+              s(:call, nil, :foo),
+              s(:resbody, s(:array), s(:call, nil, :bar), s(:call, nil, :bar))),
+            s(:call, nil, :bar),
+            s(:if,
+              s(:call, nil, :foo),
+              s(:return, s(:call, nil, :bar)),
+              s(:call, nil, :bar)))
+
+    out = "def check\n  begin\n    foo\n  rescue\n    bar\n    bar\n  end\n  bar\n  if foo then\n    return bar\n  else\n    bar\n  end\nend"
+
+    assert_parse inn, out
+  end
+
+  def test_bug_044
+    inn = s(:if,
+            s(:call,
+              s(:match3, s(:lit, /a/), s(:call, nil, :foo)),
+              :or,
+              s(:call, nil, :bar)),
+            s(:call, nil, :puts, s(:call, nil, :bar)),
+            nil)
+    out = "puts(bar) if (foo =~ /a/).or(bar)"
+
+    assert_parse inn, out
+  end
+
+  def test_bug_045
+    # return foo.baaaaaaar ? ::B.newsss(true) : ::B.newadsfasdfasdfasdfasdsssss(false)
+
+    inn = s(:return,
+            s(:if,
+              s(:call, s(:call, nil, :foo), :baaaaaaar),
+              s(:call, s(:colon3, :B), :newsss, s(:true)),
+              s(:call, s(:colon3, :B), :newadsfasdfasdfasdfasdsssss, s(:false))))
+
+    out = "return (if foo.baaaaaaar then\n  ::B.newsss(true)\nelse\n  ::B.newadsfasdfasdfasdfasdsssss(false)\nend)"
+
+    assert_parse inn, out
   end
 
   def test_attr_writer_double
     inn = s(:defn, :same=, s(:args, :o),
             s(:iasgn, :@same, s(:lvar, :o)), s(:iasgn, :@diff, s(:lvar, :o)))
     out = "def same=(o)\n  @same = o\n  @diff = o\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_attr_writer_same_name_diff_body
     inn = s(:defn, :same=, s(:args, :o), s(:iasgn, :@same, s(:lit, 42)))
     out = "def same=(o)\n  @same = 42\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_attr_writer_same
@@ -181,7 +276,7 @@ class TestRuby2Ruby < R2RTestCase
 
     inn = s(:defn, :same=, s(:args, :o), s(:iasgn, :@same , s(:lvar, :o)))
     out = "attr_writer :same"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_dregx_slash
@@ -189,32 +284,32 @@ class TestRuby2Ruby < R2RTestCase
 
     inn = util_thingy(:dregx)
     out = '/a"b#{(1 + 1)}c"d\/e/'
-    util_compare inn, out, /a"b2c"d\/e/
+    assert_parse inn, out, /a"b2c"d\/e/
   end
 
   def test_dstr_quote
     inn = util_thingy(:dstr)
     out = '"a\"b#{(1 + 1)}c\"d/e"'
-    util_compare inn, out, 'a"b2c"d/e'
+    assert_parse inn, out, 'a"b2c"d/e'
   end
 
   def test_dsym_quote
     inn = util_thingy(:dsym)
     out = ':"a\"b#{(1 + 1)}c\"d/e"'
-    util_compare inn, out, :'a"b2c"d/e'
+    assert_parse inn, out, :'a"b2c"d/e'
   end
 
   def test_lit_regexp_slash
     do_not_check_sexp! # dunno why on this one
 
-    util_compare s(:lit, /blah\/blah/), '/blah\/blah/', /blah\/blah/
+    assert_parse s(:lit, /blah\/blah/), '/blah\/blah/', /blah\/blah/
   end
 
   def test_call_kwsplat
     inn = s(:call, nil, :test_splat, s(:hash, s(:kwsplat, s(:call, nil, :testing))))
     out = "test_splat(**testing)"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_call_arg_assoc_kwsplat
@@ -223,14 +318,14 @@ class TestRuby2Ruby < R2RTestCase
            s(:hash, s(:lit, :kw), s(:lit, 2), s(:kwsplat, s(:lit, 3))))
     out = "f(1, :kw => 2, **3)"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_call_kwsplat_x
     inn = s(:call, nil, :a, s(:hash, s(:kwsplat, s(:lit, 1))))
     out = "a(**1)"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_defn_kwargs
@@ -239,7 +334,7 @@ class TestRuby2Ruby < R2RTestCase
             s(:nil))
     out = "def initialize(arg, keyword: nil, **args)\n  # do nothing\nend"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_defn_kwargs2
@@ -251,20 +346,20 @@ class TestRuby2Ruby < R2RTestCase
             s(:nil))
     out = "def initialize(arg, kw1: nil, kw2: nil, **args)\n  # do nothing\nend"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_call_self_index
-    util_compare s(:call, nil, :[], s(:lit, 42)), "self[42]"
+    assert_parse s(:call, nil, :[], s(:lit, 42)), "self[42]"
   end
 
   def test_call_self_index_equals
-    util_compare(s(:attrasgn, s(:self), :[]=, s(:lit, 42), s(:lit, 24)),
+    assert_parse(s(:attrasgn, s(:self), :[]=, s(:lit, 42), s(:lit, 24)),
                  "self[42] = 24")
   end
 
   def test_call_self_index_equals_array
-    util_compare(s(:attrasgn, s(:self), :[]=, s(:lit, 1), s(:lit, 2), s(:lit, 3)),
+    assert_parse(s(:attrasgn, s(:self), :[]=, s(:lit, 1), s(:lit, 2), s(:lit, 3)),
                  "self[1, 2] = 3")
   end
 
@@ -274,7 +369,7 @@ class TestRuby2Ruby < R2RTestCase
             s(:call, nil, :b))
     out = "method({ :a => 1 }, b)"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_call_arglist_hash_first_last
@@ -284,7 +379,7 @@ class TestRuby2Ruby < R2RTestCase
             s(:hash, s(:lit, :c), s(:lit, 1)))
     out = "method({ :a => 1 }, b, :c => 1)"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_call_arglist_hash_last
@@ -293,7 +388,7 @@ class TestRuby2Ruby < R2RTestCase
             s(:hash, s(:lit, :a), s(:lit, 1)))
     out = "method(b, :a => 1)"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_call_arglist_if
@@ -306,7 +401,7 @@ class TestRuby2Ruby < R2RTestCase
               s(:call, nil, :d)))
 
     out = "(a + (b ? (c) : (d)))"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_defn_kwsplat
@@ -337,7 +432,7 @@ class TestRuby2Ruby < R2RTestCase
               s(:evstr, s(:lvar, :b))))
     out = 'nil.x { |(a, b)| "#{a}=#{b}" }'
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_masgn_wtf
@@ -357,7 +452,7 @@ class TestRuby2Ruby < R2RTestCase
 
     out = "k, v = *line.split(/\\=/, 2)\nself[k] = v.strip\n"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_masgn_splat_wtf
@@ -369,14 +464,14 @@ class TestRuby2Ruby < R2RTestCase
                 :split,
                 s(:lit, /\=/), s(:lit, 2))))
     out = 'k, v = *line.split(/\\=/, 2)'
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_match3_asgn
     inn = s(:match3, s(:lit, //), s(:lasgn, :y, s(:call, nil, :x)))
     out = "(y = x) =~ //"
     # "y = x =~ //", which matches on x and assigns to y (not what sexp says).
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_safe_attrasgn
@@ -387,7 +482,7 @@ class TestRuby2Ruby < R2RTestCase
 
     out = "x&.y = 1"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_safe_call
@@ -399,7 +494,7 @@ class TestRuby2Ruby < R2RTestCase
               s(:lit, 1))
 
     out ="x&.y&.z(1)"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_safe_call_binary
@@ -409,7 +504,29 @@ class TestRuby2Ruby < R2RTestCase
             s(:lit, 1))
 
     out = "x&.>(1)"
-    util_compare inn, out
+    assert_parse inn, out
+  end
+
+  def test_safe_op_asgn
+    inn = s(:safe_op_asgn,
+            s(:call, nil, :x),
+            s(:call, nil, :z, s(:lit, 1)),
+            :y,
+            :+)
+
+    out = "x&.y += z(1)"
+    assert_parse inn, out
+  end
+
+  def test_safe_op_asgn2
+    inn = s(:safe_op_asgn2,
+            s(:call, nil, :x),
+            :y=,
+            :"||",
+            s(:lit, 1))
+
+    out = "x&.y ||= 1"
+    assert_parse inn, out
   end
 
   def test_splat_call
@@ -421,7 +538,7 @@ class TestRuby2Ruby < R2RTestCase
                 s(:lit, /\=/), s(:lit, 2))))
 
     out = 'x(*line.split(/\=/, 2))'
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_resbody_block
@@ -433,7 +550,7 @@ class TestRuby2Ruby < R2RTestCase
               s(:call, nil, :x3)))
 
     out = "begin\n  x1\nrescue\n  x2\n  x3\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_resbody_short_with_begin_end
@@ -442,7 +559,7 @@ class TestRuby2Ruby < R2RTestCase
             s(:call, nil, :blah),
             s(:resbody, s(:array), s(:array)))
     out = "blah rescue []"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_resbody_short_with_begin_end_multiple
@@ -453,7 +570,7 @@ class TestRuby2Ruby < R2RTestCase
               s(:call, nil, :log),
               s(:call, nil, :raise)))
     out = "begin\n  blah\nrescue\n  log\n  raise\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_resbody_short_with_defn_multiple
@@ -467,7 +584,7 @@ class TestRuby2Ruby < R2RTestCase
                 s(:call, nil, :log),
                 s(:call, nil, :raise))))
     out = "def foo\n  a = 1\nrescue\n  log\n  raise\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_regexp_options
@@ -479,7 +596,7 @@ class TestRuby2Ruby < R2RTestCase
               4),
             s(:str, "a"))
     out = '"a" =~ /abc#{x}def/m'
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_resbody_short_with_rescue_args
@@ -487,7 +604,7 @@ class TestRuby2Ruby < R2RTestCase
             s(:call, nil, :blah),
             s(:resbody, s(:array, s(:const, :A), s(:const, :B)), s(:array)))
     out = "begin\n  blah\nrescue A, B\n  []\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_call_binary_call_with_hash_arg
@@ -503,7 +620,7 @@ class TestRuby2Ruby < R2RTestCase
 
     out = "(args << { :key => 24 }) if 42"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_binary_operators
@@ -511,20 +628,28 @@ class TestRuby2Ruby < R2RTestCase
     Ruby2Ruby::BINARY.each do |op|
       inn = s(:call, s(:lit, 1), op, s(:lit, 2))
       out = "(1 #{op} 2)"
-      util_compare inn, out
+      assert_parse inn, out
+    end
+  end
+
+  def test_binary_operators_with_multiple_arguments
+    Ruby2Ruby::BINARY.each do |op|
+      inn = s(:call, s(:lvar, :x), op, s(:lit, 2), s(:lit, 3))
+      out = "x.#{op}(2, 3)"
+      assert_parse inn, out
     end
   end
 
   def test_call_empty_hash
     inn = s(:call, nil, :foo, s(:hash))
     out = "foo({})"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_if_empty
     inn = s(:if, s(:call, nil, :x), nil, nil)
     out = "if x then\n  # do nothing\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_interpolation_and_escapes
@@ -535,60 +660,71 @@ class TestRuby2Ruby < R2RTestCase
               s(:str, "m"),
               s(:evstr, s(:call, nil, :message)),
               s(:str, "\e[0m   ")))
-    out = "log_entry = \"  \e[#\{message_color}m#\{message}\e[0m   \""
+    out = "log_entry = \"  \\e[#\{message_color}m#\{message}\\e[0m   \""
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_class_comments
     inn = s(:class, :Z, nil)
     inn.comments = "# x\n# y\n"
     out = "# x\n# y\nclass Z\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_module_comments
     inn = s(:module, :Z)
     inn.comments = "# x\n# y\n"
     out = "# x\n# y\nmodule Z\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_method_comments
     inn = s(:defn, :z, s(:args), s(:nil))
     inn.comments = "# x\n# y\n"
     out = "# x\n# y\ndef z\n  # do nothing\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_basic_ensure
     inn = s(:ensure, s(:lit, 1), s(:lit, 2))
     out = "begin\n  1\nensure\n  2\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_nested_ensure
     inn = s(:ensure, s(:lit, 1), s(:ensure, s(:lit, 2), s(:lit, 3)))
     out = "begin\n  1\nensure\n  begin\n    2\n  ensure\n    3\n  end\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_nested_rescue
     inn = s(:ensure, s(:lit, 1), s(:rescue, s(:lit, 2), s(:resbody, s(:array), s(:lit, 3))))
     out = "begin\n  1\nensure\n  2 rescue 3\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_nested_rescue_exception
     inn = s(:ensure, s(:lit, 1), s(:rescue, s(:lit, 2), s(:resbody, s(:array, s(:const, :Exception)), s(:lit, 3))))
     out = "begin\n  1\nensure\n  begin\n    2\n  rescue Exception\n    3\n  end\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_nested_rescue_exception2
     inn = s(:ensure, s(:rescue, s(:lit, 2), s(:resbody, s(:array, s(:const, :Exception)), s(:lit, 3))), s(:lit, 1))
     out = "begin\n  2\nrescue Exception\n  3\nensure\n  1\nend"
-    util_compare inn, out
+    assert_parse inn, out
+  end
+
+  def test_op_asgn
+    inn = s(:op_asgn,
+            s(:call, nil, :x),
+            s(:call, nil, :z, s(:lit, 1)),
+            :y,
+            :+)
+
+    out = "x.y += z(1)"
+    assert_parse inn, out
   end
 
   def test_rescue_block
@@ -598,7 +734,7 @@ class TestRuby2Ruby < R2RTestCase
               s(:call, nil, :beta),
               s(:call, nil, :gamma)))
     out = "begin\n  alpha\nrescue\n  beta\n  gamma\nend"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_array_adds_parens_around_rescue
@@ -607,7 +743,7 @@ class TestRuby2Ruby < R2RTestCase
             s(:rescue, s(:call, nil, :b), s(:resbody, s(:array), s(:call, nil, :c))))
     out = "[a, (b rescue c)]"
 
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_call_arglist_rescue
@@ -618,7 +754,7 @@ class TestRuby2Ruby < R2RTestCase
               s(:call, nil, :a),
               s(:resbody, s(:array), s(:call, nil, :b))))
     out = "method((a rescue b))"
-    util_compare inn, out
+    assert_parse inn, out
   end
 
   def test_unless_vs_if_not
@@ -626,14 +762,17 @@ class TestRuby2Ruby < R2RTestCase
     rb2 = "a if (not b)"
     rb3 = "a if ! b"
 
-    util_compare Ruby18Parser.new.parse(rb1), rb1
-    util_compare Ruby19Parser.new.parse(rb1), rb1
+    assert_parse Ruby18Parser.new.parse(rb1), rb1
+    assert_parse Ruby19Parser.new.parse(rb1), rb1
+    assert_parse Ruby25Parser.new.parse(rb1), rb1
 
-    util_compare Ruby18Parser.new.parse(rb2), rb1
-    util_compare Ruby19Parser.new.parse(rb2), rb2
+    assert_parse Ruby18Parser.new.parse(rb2), rb1
+    assert_parse Ruby19Parser.new.parse(rb2), rb1
+    assert_parse Ruby25Parser.new.parse(rb2), rb1
 
-    util_compare Ruby18Parser.new.parse(rb3), rb1
-    util_compare Ruby19Parser.new.parse(rb3), rb2
+    assert_parse Ruby18Parser.new.parse(rb3), rb1
+    assert_parse Ruby19Parser.new.parse(rb3), rb1
+    assert_parse Ruby25Parser.new.parse(rb3), rb1
   end
 
   def assert_parse sexp, expected_ruby, expected_eval = nil
@@ -643,7 +782,6 @@ class TestRuby2Ruby < R2RTestCase
     assert_equal expected_ruby, @processor.process(sexp), "sexp -> ruby"
     assert_equal expected_eval, eval(expected_ruby) if expected_eval
   end
-  alias util_compare assert_parse
 
   def util_thingy(type)
     s(type,
